@@ -7,6 +7,6 @@ Copyright (C) 2022 Johannes Haug.
 from .mean_drift_performance_deterioration import mean_drift_performance_deterioration
 from .mean_drift_restoration_time import mean_drift_restoration_time
 from .noise_variability import noise_variability
-from .river_classification_metric import river_classification_metric
+from .river_metric import river_metric
 
-__all__ = ['mean_drift_performance_deterioration', 'mean_drift_restoration_time', 'noise_variability', 'river_classification_metric']
+__all__ = ['mean_drift_performance_deterioration', 'mean_drift_restoration_time', 'noise_variability', 'river_metric']
